%% Reproduce results of SHLR-SV in the follwing paper:
%% Xinlin Zhang,  Hengfa Lu,  Di Guo, Zongying Lai, Huihui Ye, Xi Peng, Bo Zhao, Xiaobo Qu, Accelerated MRI Reconstruction With Separable and Enhanced Low-Rank Hankel Regularization, IEEE Transactions on Medical Imaging, 41(9): 2486-2498, 2022.
%% Created by Xinlin Zhang
%% Corresponding Author: Xiaobo Qu
%% Homepage: http://csrc.xmu.edu.cn
%% Email: quxiaobo <|at|> xmu.edu.cn
%% Affiliations: Computational Sensing Group (CSG), Departments of Electronic Science, Xiamen University, Xiamen 361005, China
%% All rights are reserved by CSG.
%% 2022-03
%%
clc
clear
close all
warning off
%%
currentFolder = pwd;
addpath(genpath(currentFolder));

%% load  undersampled k-space data
load k_sampled.mat
load m_2D_random_R3.mat

% If you use your own image data, please process the image as follows to obtain the k_sampled
% k_ori = fft2c(im_ori);
% k_sampled  = mask .* k_ori;

[row, col, coil] = size(k_sampled);
%% Recon by SHLR-SV
% parameter setting for SHLR-SV
params.lambda = 1e6;
params.lambda_1 = 1e4;
% params.kSize = [5,5];      % SPIRiT kernel size
% params.CalibTyk = 0.003;   % Tykhonov regularization in SPIRiT calibration
% params.k_row = round((row+1)/(2*coil+1));   % pencil parameter for constucting Hankel matrices of rows
% params.k_col = round((col+1)/(2*coil+1));   % pencil parameter for constucting Hankel matrices of columns
% params.beta = 1;
% params.MaxIter = 50;
% params.Tol = 1e-5;
% params.pcg_tol = 2*1e-6;

% parallel computing
% parallel_cores = 20;
% handle_parallel = parpool(parallel_cores);

% reconstruction
tic
im_rec_SHLR_SV  = Solver_SHLR_SV(k_sampled, mask, params);
runtime = toc


figure,imshow(sos(im_rec_SHLR_SV),[0 1])